# Pinnacle Python SDK 1.0.0

Welcome to the Pinnacle SDK documentation. This guide will help you get started with integrating and using the Pinnacle SDK in your project.

## Versions

- API version: `4.0.0`
- SDK version: `1.0.0`

## About the API

All about bets, place bets, get your bet history or current bet status. # Authentication Please note that API has restriction that client password can be maximum up 10 characters long. API uses HTTP Basic access authentication. You need to send Authorization HTTP Request header: `Authorization: Basic <Base64 value of UTF-8 encoded  username:password >` Example: `Authorization: Basic U03MyOT23YbzMDc6d3c3O1DQ1`

## Table of Contents

- [Setup & Configuration](#setup--configuration)
  - [Supported Language Versions](#supported-language-versions)
  - [Installation](#installation)
- [Authentication](#authentication)
  - [Basic Authentication](#basic-authentication)
- [Services](#services)
- [Models](#models)
- [License](#license)

## Setup & Configuration

### Supported Language Versions

This SDK is compatible with the following versions: `Python >= 3.7`

### Installation

To get started with the SDK, we recommend installing using `pip`:

```bash
pip install pinnacle-bets-client
```

## Authentication

### Basic Authentication

The Pinnacle API uses Basic Authentication.

You need to provide your username and password when initializing the SDK.

#### Setting the Username and Password

When you initialize the SDK, you can set the username and password as follows:

```py
Pinnacle(
    username="YOUR_USERNAME",
    password="YOUR_PASSWORD"
)
```

If you need to set or update the username and password after initializing the SDK, you can use:

```py
sdk.set_basic_auth("YOUR_USERNAME", "YOUR_PASSWORD")
```

## Services

The SDK provides various services to interact with the API.

<details> 
<summary>Below is a list of all available services with links to their detailed documentation:</summary>

| Name                                                                   |
| :--------------------------------------------------------------------- |
| [PlaceBetsService](documentation/services/PlaceBetsService.md)         |
| [GetBetsService](documentation/services/GetBetsService.md)             |
| [BettingStatusService](documentation/services/BettingStatusService.md) |

</details>

## Models

The SDK includes several models that represent the data structures used in API requests and responses. These models help in organizing and managing the data efficiently.

<details> 
<summary>Below is a list of all available models with links to their detailed documentation:</summary>

| Name                                                                                             | Description                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          |
| :----------------------------------------------------------------------------------------------- | :  |
| [PlaceBetRequest](documentation/models/PlaceBetRequest.md)                                       | Request to place a bet.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [PlaceStraightBetResponse](documentation/models/PlaceStraightBetResponse.md)                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [PlaceParlayBetRequest](documentation/models/PlaceParlayBetRequest.md)                           | Request to place a bet                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| [PlaceParlayBetResponse](documentation/models/PlaceParlayBetResponse.md)                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [PlaceTeaserBetRequest](documentation/models/PlaceTeaserBetRequest.md)                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [PlaceTeaserBetResponse](documentation/models/PlaceTeaserBetResponse.md)                         |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [MultiBetRequestSpecialBetRequest](documentation/models/MultiBetRequestSpecialBetRequest.md)     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [MultiBetResponseSpecialBetResponse](documentation/models/MultiBetResponseSpecialBetResponse.md) |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [GetBetsByTypeResponseV4](documentation/models/GetBetsByTypeResponseV4.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [Betlist](documentation/models/Betlist.md)                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [BetStatuses](documentation/models/BetStatuses.md)                                               |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [SortDir](documentation/models/SortDir.md)                                                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [BetsGetBetsByTypeV4BetType](documentation/models/BetsGetBetsByTypeV4BetType.md)                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [BettingStatusResponse](documentation/models/BettingStatusResponse.md)                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [OddsFormat](documentation/models/OddsFormat.md)                                                 | Bet odds format. <br>AMERICAN = American odds format, <br>DECIMAL = Decimal (European) odds format, <br>HONGKONG = Hong Kong odds format, <br>INDONESIAN = Indonesian odds format, <br>MALAY = Malaysian odds format <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| [PlaceBetRequestWinRiskStake](documentation/models/PlaceBetRequestWinRiskStake.md)               | Whether the stake amount is risk or win amount.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [FillType](documentation/models/FillType.md)                                                     | NORMAL - bet will be placed on specified stake. <br>FILLANDKILL - If the stake is over the max limit, bet will be placed on max limit, otherwise it will be placed on specified stake. <br>FILLMAXLIMIT - bet will be places on max limit, stake amount will be ignored. Please note that maximum limits can change at any moment, which may result in risking more than anticipated. This option is replacement of isMaxStakeBet from v1/bets/place'<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| [PlaceBetRequestBetType](documentation/models/PlaceBetRequestBetType.md)                         | Bet type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| [Team](documentation/models/Team.md)                                                             | Team type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [PlaceBetRequestSide](documentation/models/PlaceBetRequestSide.md)                               | Side type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [PlaceStraightBetResponseStatus](documentation/models/PlaceStraightBetResponseStatus.md)         | Status of the response.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [PlaceStraightBetResponseErrorCode](documentation/models/PlaceStraightBetResponseErrorCode.md)   | If Status is PROCESSED_WITH_ERROR, errorCode will be in the response. <br><br>ALL_BETTING_CLOSED = Betting is not allowed at this moment. This may happen during system maintenance, <br>ALL_LIVE_BETTING_CLOSED = Live betting is not allowed at this moment. This may happen during system maintenance, <br>ABOVE_EVENT_MAX = Bet cannot be placed because client exceeded allowed maximum of risk on a line, <br>ABOVE_MAX_BET_AMOUNT = Stake is above allowed maximum amount, <br>BELOW_MIN_BET_AMOUNT = Stake is below allowed minimum amount, <br>BLOCKED_BETTING = Betting is suspended for the client, <br>BLOCKED_CLIENT = Client is no longer active, <br>INSUFFICIENT_FUNDS = Bet is submitted by a client with insufficient funds, <br>INVALID_COUNTRY = Client country is not allowed for betting, <br>INVALID_EVENT = Invalid eventid, <br>INVALID_ODDS_FORMAT = If a bet was submitted with the odds format that is not allowed for the client, <br>LINE_CHANGED = Bet is submitted on a line that has changed, <br>OFFLINE_EVENT = Bet is submitted on an event that is offline or the submitted line is not offered at the moment due to points/handicap change or the submitted bet type is just not offered at the moment, <br>PAST_CUTOFFTIME = Bet is submitted on a game after the betting cutoff time, <br>RED_CARDS_CHANGED = Bet is submitted on a live soccer event with changed red card count, <br>SCORE_CHANGED = Bet is submitted on a live soccer event with changed score, <br>TIME_RESTRICTION = Bet is submitted within too short of a period from the same bet previously placed by a client, <br>DUPLICATED_REQUEST = Request with the same uniqueRequestId was already processed. Please set the new value if you still want the request to be processed, <br>INCOMPLETE_CUSTOMER_BETTING_PROFILE = System configuration issue, <br>INVALID_CUSTOMER_PROFILE = System configuration issue, <br>LIMITS_CONFIGURATION_ISSUE = System configuration issue, <br>RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = Client has reached his total loss limit, <br>RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = Client has reached his total risk limit, <br>SYSTEM_ERROR_3 = Unexpected error, <br>LICENCE_RESTRICTION_LIVE_BETTING_BLOCKED - Live betting blocked due to licence restrictions, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br> |
| [ParlayLegRequest](documentation/models/ParlayLegRequest.md)                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [RoundRobinOptions](documentation/models/RoundRobinOptions.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [ParlayLegRequestLegBetType](documentation/models/ParlayLegRequestLegBetType.md)                 | Only SPREAD, MONEYLINE and TOTAL_POINTS are supported.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| [ParlayLegRequestSide](documentation/models/ParlayLegRequestSide.md)                             | Chosen side type. This is needed only for TOTAL_POINTS bet type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [PlaceParlayBetResponseStatus](documentation/models/PlaceParlayBetResponseStatus.md)             | Status of the response.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| [PlaceParlayBetResponseErrorCode](documentation/models/PlaceParlayBetResponseErrorCode.md)       | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br><br>ABOVE_MAX_BET_AMOUNT = Stake is above allowed maximum amount, <br>ALL_BETTING_CLOSED = Betting is not allowed at this moment, <br>BELOW_MIN_BET_AMOUNT = Stake is below allowed minimum amount, <br>BLOCKED_BETTING = Betting is suspended for the client, <br>BLOCKED_CLIENT = Client is no longer active, <br>INSUFFICIENT_FUNDS = Bet is submitted by a client with insufficient funds, <br>INVALID_COUNTRY = Client country is not allowed for betting, <br>INVALID_LEGS = One or more legs are invalid, <br>INVALID_ODDS_FORMAT = If a bet was submitted with the odds format that is not allowed for the client, <br>INVALID_ROUND_ROBIN_OPTIONS = Round robin options are invalid (i.e. does not match with number of legs), <br>ROUND_ROBIN_DISALLOWED = Round robin is disallowed for one of the leagues, <br>TOO_MANY_LEGS = Maximum of 10 legs can be specified, <br>TOO_FEW_LEGS = At least 2 legs are required for Parlay, <br>RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = Client has reached his total loss limit, <br>RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = Client has reached his total risk limit, <br>INVALID_REQUEST = Request has invalid parameters, <br>DUPLICATED_REQUEST = Request with the same uniqueRequestId was already processed. Please set the new value if you still want the request to be processed, <br>SYSTEM_ERROR_3 = Unexpected error <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                |
| [RoundRobinOptionWithOdds](documentation/models/RoundRobinOptionWithOdds.md)                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [ParlayLegResponse](documentation/models/ParlayLegResponse.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [RoundRobinOption](documentation/models/RoundRobinOption.md)                                     |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [ParlayLegResponseStatus](documentation/models/ParlayLegResponseStatus.md)                       | Status of the request.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| [ParlayLegResponseErrorCode](documentation/models/ParlayLegResponseErrorCode.md)                 | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br>CANNOT_PARLAY_LIVE_GAME = The wager is placed on Live game, <br>CORRELATED = The leg is correlated with another one, <br>EVENT_NO_LONGER_AVAILABLE_FOR_BETTING = The event is no longer offered, <br>EVENT_NOT_OFFERED_FOR_PARLAY = The event is not offered for parlaying, <br>INVALID_EVENT = Live betting is not allowed at this moment, <br>INVALID_LEG_BET_TYPE = Leg bet type is not accepted for parlaying. Accepted values are SPREAD, MONEYLINE, TOTAL_POINTS, <br>INVALID_PARLAY_BET = The leg did not validated due to error on Parlay Bet. Check the error PlaceParlayBet response for error details, <br>LINE_CHANGED = Bet is submitted on a line that has changed, <br>LINE_DOES_NOT_BELONG_TO_EVENT = LineId does not match the EventId specified in the request, <br>LISTED_PITCHERS_SELECTION_ERROR = If bet was submitted with pitcher1MustStart and/or pitcher2MustStart parameters with values that are not allowed, <br>ODDS_NO_LONGER_OFFERED_FOR_PARLAY_1 = Due to line change odds are not offered for parlaying, <br>ODDS_NO_LONGER_OFFERED_FOR_PARLAY_2 = Due to line change odds are not offered for parlaying, <br>ODDS_NO_LONGER_OFFERED_FOR_PARLAY_3 = Due to line change odds are not offered for parlaying, <br>OFFLINE_EVENT = Bet is submitted on an event that is offline or with incorrect lineId, <br>PAST_CUTOFFTIME = Bet is submitted on a game after the betting cutoff time, <br>SYSTEM_ERROR_1 = Unexpected error, <br>SYSTEM_ERROR_2 = Unexpected error, <br>SYSTEM_ERROR_3 = Unexpected error, <br>LINE_IS_NOT_AVAILABLE = Line is not available for the specified Parlay Leg, <br>PERIOD_IS_DISALLOWED_FOR_SAME_GAME_PARLAY = Period is not allowed to be parlayed on a same event, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| [TeaserBetLeg](documentation/models/TeaserBetLeg.md)                                             |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [TeaserBetLegBetType](documentation/models/TeaserBetLegBetType.md)                               | Leg bet type can be SPREAD or TOTAL_POINTS                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [TeaserBetLegSide](documentation/models/TeaserBetLegSide.md)                                     | Chosen side type. This is needed only for TOTAL_POINTS bet type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [PlaceTeaserBetResponseErrorCode](documentation/models/PlaceTeaserBetResponseErrorCode.md)       | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br>ABOVE_MAX_BET_AMOUNT = Bet is above the maximum allowed, <br>ALL_BETTING_CLOSED = The wagering is disabled in the system (not related to a customer), <br>BELOW_MIN_BET_AMOUNT = Bet is below the minimum allowed, <br>BLOCKED_BETTING = Betting is suspended for the client, <br>BLOCKED_CLIENT = Customer is inactive in the system, <br>DOUBLE_HIT = The website submitted the same bet more than once, <br>DUPLICATE_CLIENT_REFERENCE_ID = The teaser unique id and/or one of the leg unique id are the same, <br>INCOMPLETE_CUSTOMER_BETTING_PROFILE = The customer does not exist, <br>INSUFFICIENT_FUNDS = The risk amount is above the customer’s available balance, <br>INVALID_COUNTRY = Current location is proscribed, <br>INVALID_CUSTOMER_PROFILE = Either the customer does not exist OR the customer business rules are not verified, <br>INVALID_LEGS = One or more legs are not verified, <br>INVALID_REQUEST = Teaser request is not valid, <br>ODDS_FORMAT_MISMATCH = Agent customer’s odds format differs from wager request odds format,<br>TEASER_DOES_NOT_EXIST = Teaser does not exist in the system, <br>SAME_EVENT_ONLY_REQUIRED = Legs required to be for the same game only. Specified in the Teaser Specifications, <br>SYSTEM_ERROR_1 = System error, <br>SYSTEM_ERROR_2 = System error, <br>SYSTEM_ERROR_3 = System error, <br>TOO_FEW_LEGS = Legs count is below Min Picks specified in the Teaser Specifications, <br>TOO_MANY_LEGS = Legs count is above Max Picks specified in the Teaser Specifications,<br>DUPLICATED_REQUEST = Request with the same uniqueRequestId was already processed. Please set the new value if you still want the request to be processed, <br>RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = Client has reached his total loss limit, <br>RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = Client has reached his total risk limit<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| [PlaceTeaserBetLegResponse](documentation/models/PlaceTeaserBetLegResponse.md)                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [PlaceTeaserBetLegResponseErrorCode](documentation/models/PlaceTeaserBetLegResponseErrorCode.md) | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br>CANNOT_TEASER_LIVE_GAME = Teaser is not allowed on a live game, <br>CHECK_TEASER_ERROR = The teaser is invalid, check the teaser error for more details, <br>INVALID_EVENT = The game is not found in the system, <br>INVALID_LEG_BET = The wager is not verified, <br>INVALID_LEG_BET_TYPE = Wager type is not “teasable”, can be either Spread or Total, <br>LINE_CHANGED = Wager is placed on a line that has changed, <br>LINE_DOES_NOT_BELONG_TO_EVENT = There was no game found for the wager, <br>OFFLINE_EVENT = Either the game is offline OR there was no game found for the wager, <br>PAST_CUTOFFTIME = Wager is placed on a game after the cutoff time, <br>POINTS_ARE_NOT_ADJUSTED = The teaser points were not adjusted, <br>SYSTEM_ERROR_1 = System error, <br>SYSTEM_ERROR_2 = System error, <br>WAGER_DATA_MISSING = Wager is denied due to insufficient information available for validation, <br>LINE_IS_NOT_AVAILABLE = Line is not available for the specified Teaser Leg, <br>TEASER_IS_NOT_ENABLED = Teaser is not available for the specified leg, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [SpecialBetRequest](documentation/models/SpecialBetRequest.md)                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [SpecialBetRequestWinRiskStake](documentation/models/SpecialBetRequestWinRiskStake.md)           | Whether the stake amount is risk or win amount.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [SpecialBetResponse](documentation/models/SpecialBetResponse.md)                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [SpecialBetResponseStatus](documentation/models/SpecialBetResponseStatus.md)                     | Status of the request.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| [SpecialBetResponseErrorCode](documentation/models/SpecialBetResponseErrorCode.md)               | When Status is PROCESSED_WITH_ERROR, provides a code indicating the specific problem.<br><br>ALL_BETTING_CLOSED = Betting is not allowed at this moment. This may happen during system maintenance. <br> ABOVE_MAX_BET_AMOUNT = Stake is above allowed maximum amount, <br> BELOW_MIN_BET_AMOUNT = Stake is below allowed minimum amount, <br> BLOCKED_BETTING = Betting is suspended for the client, <br> BLOCKED_CLIENT = Client is no longer active, <br> CONTEST_NOT_FOUND = Incorrect contest id provided or contest is no longer available, <br> DUPLICATED_REQUEST = UniqueRequestId must be unique for each bet, <br> INCOMPLETE_CUSTOMER_BETTING_PROFILE = Customer profile could not be loaded, <br> INSUFFICIENT_FUNDS = Bet is submitted by a client with insufficient funds, <br> INVALID_COUNTRY = Client country is not allowed for betting, <br> INVALID_REQUEST = Special bet request is not valid, <br> LINE_CHANGED = Bet is submitted on a line that has changed, <br> PAST_CUTOFFTIME = Bet is submitted on a game after the betting cutoff time, <br> RESPONSIBLE_BETTING_LOSS_LIMIT_EXCEEDED = Self-imposed loss limit exceeded, <br> RESPONSIBLE_BETTING_RISK_LIMIT_EXCEEDED = Self-imposed risk limit exceeded, <br> SYSTEM_ERROR_1 = Unexpected error, <br> SYSTEM_ERROR_2 = Unexpected error, <br> UNIQUE_REQUEST_ID_REQUIRED = UniqueRequestId is missing, <br> INVALID_CUSTOMER_PROFILE = System configuration issue, <br>BETTING_SUSPENDED - Due to anomalous market circumstances bets are not currently being accepted on this line. Try again with next LineId.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 |
| [StraightBetV4](documentation/models/StraightBetV4.md)                                           |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [ParlayBet](documentation/models/ParlayBet.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [TeaserBet](documentation/models/TeaserBet.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [SpecialBet](documentation/models/SpecialBet.md)                                                 |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [ManualBet](documentation/models/ManualBet.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [StraightBetV4BetStatus](documentation/models/StraightBetV4BetStatus.md)                         | Bet Status. <br><br>ACCEPTED = Bet was accepted.<br>PUSHED = Bet was pushed.<br>CANCELLED = Bet is cancelled as per Pinnacle betting rules. <br>LOST = The bet is settled as lose. <br>PENDING_ACCEPTANCE = This status is reserved only for live bets. If a live bet is placed during danger zone or live delay is applied, it will be in PENDING_ACCEPTANCE , otherwise in ACCEPTED status. From this status bet can go to ACCEPTED or NOT_ACCEPTED status. <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status. <br>NOT_ACCEPTED = Bet was not accepted. Bet can be in this status only if it was previously in PENDING_ACCEPTANCE status. <br>WON = The bet is settled as won. <br>HALF_WON_HALF_PUSHED = The bet is settled as half won half pushed. Only for asian handicap bets. <br>HALF_LOST_HALF_PUSHED = The bet is settled as half lost half pushed. Only for asian handicap bets.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [StraightBetV4BetType](documentation/models/StraightBetV4BetType.md)                             | Bet type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| [CancellationReason](documentation/models/CancellationReason.md)                                 | Possible keys \: <br>_ correctTeam1Id<br>_ correctTeam2Id<br>_ correctListedPitcher1<br>_ correctListedPitcher2<br>_ correctSpread<br>_ correctTotalPoints<br>_ correctTeam1TotalPoints<br>_ correctTeam2TotalPoints<br>_ correctTeam1Score<br>_ correctTeam2Score<br>_ correctTeam1TennisSetsScore<br>_ correctTeam2TennisSetsScore<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| [StraightBetV4Side](documentation/models/StraightBetV4Side.md)                                   | Side type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [CancellationDetailsItem](documentation/models/CancellationDetailsItem.md)                       |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [ParlayBetBetStatus](documentation/models/ParlayBetBetStatus.md)                                 | Bet Status. <br><br>ACCEPTED = Bet was accepted. <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules. <br>LOST = The bet is settled as lose. <br>PENDING_ACCEPTANCE = This status is reserved only for live bets. If a live bet is placed during danger zone or live delay is applied, it will be in PENDING_ACCEPTANCE , otherwise in ACCEPTED status. From this status bet can go to ACCEPTED or REJECTED status. <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status. <br>NOT_ACCEPTED = Bet was not accepted. Bet can be in this status only if it was previously in PENDING_ACCEPTANCE status. <br>WON = The bet is settled as won. <br>PARTIAL_WON - If gross payout is greater than the stake. Only for parlays with the asian handicap legs. <br>PARTIAL_LOST - If gross payout is less or equal to the stake. Only for parlays with the asian handicap legs.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [ParlayLeg](documentation/models/ParlayLeg.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [ParlayLegLegBetType](documentation/models/ParlayLegLegBetType.md)                               | Parlay leg type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [ParlayLegLegBetStatus](documentation/models/ParlayLegLegBetStatus.md)                           | Parlay Leg status.<br>CANCELLED = The leg is canceled- the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss.<br>LOST = The leg is a loss or a push-lose. When Push-lose happens, the half of the stake on the leg will be pushed to the next leg, and the other half will be a lose. This can happen only when the leg is placed on a quarter points handicap. <br>PUSHED = The leg is a push - the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss. <br>REFUNDED = The leg is refunded - the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss. <br>WON = The leg is a won or a push-won. When Push-won happens, the half of the stake on the leg will be pushed to the next leg, and the other half is won. This can happen only when the leg is placed on a quarter points handicap.<br>HALF_WON_HALF_PUSHED = The bet is settled as half won half pushed. Only for asian handicap legs.<br>HALF_LOST_HALF_PUSHED = The bet is settled as half lost half pushed. Only for asian handicap legs. <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [ParlayLegSide](documentation/models/ParlayLegSide.md)                                           | Side type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [TeaserBetBetStatus](documentation/models/TeaserBetBetStatus.md)                                 | Bet Status. <br><br>ACCEPTED = Bet was accepted, <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules, <br>LOSE = The bet is settled as lose, <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status, <br>WON = The bet is settled as won <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| [TeaserLeg](documentation/models/TeaserLeg.md)                                                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      |
| [TeaserLegLegBetType](documentation/models/TeaserLegLegBetType.md)                               | Teaser leg type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| [TeaserLegLegBetStatus](documentation/models/TeaserLegLegBetStatus.md)                           | CANCELLED = The leg is canceled- the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss, <br>LOSE = The leg is a loss or a push-lose. When Push-lose happens, the half of the stake on the leg will be pushed to the next leg, and the other half will be a lose. This can happen only when the leg is placed on a quarter points handicap, <br>PUSHED = The leg is a push - the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss, <br>REFUNDED = The leg is refunded - the stake on this leg will be transferred to the next one. In this case the leg will be ignored when calculating the winLoss, <br>WON = The leg is a won or a push-won. When Push-won happens, the half of the stake on the leg will be pushed to the next leg, and the other half is won. This can happen only when the leg is placed on a quarter points handicap <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       |
| [TeaserLegSide](documentation/models/TeaserLegSide.md)                                           | Side type.                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           |
| [SpecialBetBetStatus](documentation/models/SpecialBetBetStatus.md)                               | Bet Status. <br>ACCEPTED = Bet was accepted, <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules, <br>LOSE = The bet is settled as lose,<br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status, <br>WON = The bet is settled as won <br>PUSHED = The bet is settled as a push.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               |
| [ManualBetBetStatus](documentation/models/ManualBetBetStatus.md)                                 | Bet Status. <br><br>ACCEPTED = Bet was accepted, <br>CANCELLED = Bet is cancelled as per Pinnacle betting rules, <br>LOSE = The bet is settled as lose, <br>REFUNDED = When an event is cancelled or when the bet is settled as push, the bet will have REFUNDED status, <br>WON = The bet is settled as won <br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    |
| [BettingStatusResponseStatus](documentation/models/BettingStatusResponseStatus.md)               | Betting status.<br>                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  |

</details>

## License

This SDK is licensed under the MIT License.

See the [LICENSE](LICENSE) file for more details.

<!-- This file was generated by liblab | https://liblab.com/ -->
